# development

## image crawler

TODO 


## backend

install the requirements: `ptyhon3 -m pip install -e .[development]`.

then just do whatever you would like.
do not forget to [test](testing.md) the code.


## frontend

TODO 
